import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";
import {H5} from "../components/Headings";
import MethodSources from "../sources/methods-sources";

export function Methods() {
  useTabNavigation();
    return (
      <>
        <Section title="Introduction" id="Introduction">
          ...
        </Section>
        <Section title="Patch Clamp" id="Patch Clamp">
          <Subesction title="Patch Clamp: A Key Tool in Electrophysiology" id="Patch Clamp1">
            <p>The patch clamp technique is a highly sensitive method for measuring ionic currents through individual ion channels in cells, making it a cornerstone of electrophysiological research. Initially developed by Erwin Neher and Bert Sakmann in the 1970s [1], this technique has evolved into various configurations, including the Whole-Cell and Single-Channel recordings [2], which provide critical insights into the functional properties of ion channels. </p>
          </Subesction>
          <Subesction title="Principles of the patch clamp technique" id="Patch Clamp2">
          <p>Patch clamp recording involves the use of a glass micropipette which is manufactured from a glass capillary through the use of a Micropipette Puller. The micropipette is then filled with an electrolyte solution, which is subsequently brought into contact with the cell membrane. By applying gentle suction, a high-resistance seal called giga seal is formed between the pipette tip and the membrane patch. This enables the measurement of ionic currents with minimal noise interference [3]. <strong>Whole-Cell Configuration</strong> records currents from the entire cell by rupturing the membrane patch, accessing the intracellular environment, and is useful for analysing overall ion channel activity and cellular responses. <strong>Single-Channel Recording</strong> measures currents through individual ion channels without rupturing the membrane, enabling high-resolution study of channel conductance, gating, and selectivity [2].</p>
          <figure>
            <iframe title="Bielefeld-CeBiTec: Patch Clamp Measurement (2024)" width="560" height="315" src="https://video.igem.org/videos/embed/0d948e57-5997-430a-a2df-815b71a2fc67?autoplay=1" frameBorder="0" allowFullScreen={true} sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>
            <figcaption> <b>Figure 1.</b> Microscopic recording of micropipette sealing of a HEK293 cell </figcaption>
          </figure>


          <p>The success of patch clamp experiments heavily depends on the composition of the solutions used. Typically, two main types of solutions are employed: The <strong>Pipette Solution</strong> in the micropipette mimics the intracellular environments, while the <strong>Bath Solution</strong> surrounds the cell and usually contains components that replicate the extracellular environment. Both solutions are meticulously designed to reflect the physiological conditions under which the cells operate, thereby ensuring that the measurements accurately reflect ion channel activity in a natural setting [2].</p>
          <figure>
            <img src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/meth-patch-clamp/bild-meth-patch-clamp.png" alt="Patch clamp setup"/>
            <figcaption><b>Figure 2.</b> Patch clamp setup</figcaption>
          </figure>
          </Subesction>
          <Subesction title="Application in CFTR gene prime editing validation" id="Patch Clamp3">
            <p>In our ongoing research project focusing on the treatment of cystic fibrosis (CF), our patch clamp measurements, performed in collaboration with Dr. Oliver Dräger from the Cellular Neurophysiology working group at Bielefeld University, serve as a powerful validation tool for the assessment of the functional correction of the CFTR gene, particularly the common F508del mutation, via prime editing. The patch clamp technique can be employed in this context to measure the resulting chloride ion channel activity which is altered by the mutation [4]. Whole-Cell recordings were performed to assess whether the corrected CFTR channels function similarly to those in healthy cells. If the chloride ion currents in the edited cells approach levels of healthy cells, this would strongly suggest successful gene editing and validate the functionality of our therapeutic approach.</p>
          </Subesction>
        </Section>

        <Section title="Cell Culture" id="Cell Culture">
          <Subesction title="HEK293 and HEK293T cell lines" id="Cell Culture1">
          <p>For testing our prime editing approach, we needed an easy-to-handle cell line with a measurable high expression of CFTR and the CFTR F508del mutation. When talking to Mattijs Bulcaen from the Laboratory of Molecular Virology and Gene Therapy at KU Leuven, he recommended to use HEK293T cell lines overexpressing CFTR they had used. HEK293 cells are a very common immortalized human cell line derived from the kidneys of a female embryo. They are particularly suited to research due to their convenient handling and transfection properties. Basic HEK293 cells were provided to us by the Cellular and Molecular Biotechnology working group at Bielefeld University led by Prof. Dr. Kristian Müller, who is also one of the Principal Investigators of our team. HEK293T cells express an additional tsA1609 allele of the SV40 large T-antigen, allowing for replication of vectors containing the SV40 origin of replication.[2] Besides the native CFTR gene, which is not expressed in HEK cells, the HEK293T cell lines used in Leuven carry another copy of the gene embedded in an expression cassette. The cassette includes a CMV promoter, which is a standard promoter used for gene overexpression in human cells derived from the human Cytomegalovirus[4], as well as a puromycin resistance co-expressed with the CFTR allowing for continuous selection of CFTR expressing cells. The whole construct was stably inserted into the genome using lentiviral transduction.1,3 </p>
          <figure>
            <img src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/meth-used-cells/mikroskopie-hek293t.png" alt="Phase contrast image of HEK293T at 20x magnification"/>
            <figcaption> <b>Figure 3.</b>Phase contrast image of HEK293T at 20x magnification</figcaption>
          </figure>
          </Subesction>
          <Subesction title="CFBE41o- cell line" id="Cell Culture2">
          <p>The CFBE41o- cell line, derived from bronchial epithelial cells of a one-year-old cystic fibrosis patient, serves as a vital model for studying cystic fibrosis. These cells closely mimic the physiological environment of the airway epithelium, allowing for more accurate studies on how CFTR mutations affect cell function and response to treatments. They were immortalized through calcium-phosphate-mediated transfection using a replication-defective pSVori plasmid that carries the simian virus 40 large T-antigen (SV40-LT). The plasmid's defective origin of replication prevents viral propagation, thus preserving essential physiological characteristics of the cells while enabling them to develop differentiated morphologies. CFBE41o- cells are homozygous for the F508del-CFTR mutation [1]. We are happy we got this cell line with permission from Prof. Dr. Zoya Ignatova, who is leader of a working group at the Institute for Biochemistry and Molecular Biology of Hamburg University and an iGEM supporter since a long time [6]. </p>
          </Subesction>
          <Subesction title="Human nasal epithelial cells (hNECs)" id="Cell Culture3">
          <p>Human nasal epithelial cells were obtained by nasal brushing, a minimally invasive method. These cells function/act as primary cultures. Cultivated in air-liquid interface (ALI) cultures and apical-out airway organoids (AOAO), they serve as a suitable model to visualise the functional epithelium of the airways in a differentiated form. The in vivo aspects of an airway disease, such as CF, can be modelled using donors with those airway diseases (5) This model is therefore particularly suitable for testing our prime editing complex. </p>
          <div className="row">
            <div className="col">
            <figure>
            <iframe title="Bielefeld-CeBiTec: ALI cell culture (2024) [English]" width="560" height="315" src="https://video.igem.org/videos/embed/ff557f5a-94be-45e6-90ca-0affa14423e3?autoplay=1&amp;muted=1" frameBorder="0" allowFullScreen={true} sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>
              <figcaption> <b>Figure 4. </b> ALI cultures of hNECs: The active cilia beat frequency of differentiated human nasal epithelial cells (hNECs) in air-liquid interface (ALI) culture is visible. This ciliary movement is crucial for mucociliary transport, which contributes to the clearance of particles and pathogens in the respiratory tract. </figcaption>
            </figure>
            </div>
            <div className="col">
            <figure>
              <iframe title="Bielefeld-CeBiTec: AOAO cell culture (2024) [English]" width="560" height="315" src="https://video.igem.org/videos/embed/058d83cf-ab09-476e-9ab2-30cd114fbc0c?autoplay=1&amp;muted=1" frameBorder="0" allowFullScreen={true} sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>
             <figcaption> <b>Figure 5. </b> Apical-Out Airway Organoid (AOAO) culture: Visible apical-out airway organoids in action. These 3D structures, which mimic the airway epithelium, allow detailed study of cellular processes such as mucociliary transport and secretory activities, in which cilia and vesicles play a key role.  </figcaption>
           </figure>
            </div>
          </div>
          </Subesction>
     

        </Section>
        <Section title="LNPs" id="LNPs">
          <Subesction title="Cytotoxicity Tests" id="Cytotoxicity Tests">
          <H5 text="Assessing the Safety of Our LNPs "></H5>
            <p>Ensuring the safety and thorough characterization of our lipid nanoparticles (LNPs) was a central part of our project, as these particles are intended for use in biological systems. We implemented a comprehensive range of assays and techniques to assess their biosafety and physical properties, ensuring their suitability for applications such as drug delivery and gene therapy. Below is an overview of the key steps we took in our assessment.</p>
          <H5 text="MTT Assay"></H5>
            <p>To evaluate the cytotoxicity of our LNPs, we conducted an MTT assay, which measures the metabolic activity of cells. This assay is based on the ability of living cells to reduce MTT, a yellow tetrazolium salt, into purple formazan crystals through NAD(P)H-dependent enzymes. Cells were treated with various concentrations of LNPs, and after dissolving the formazan crystals with DMSO, we measured absorbance. Higher absorbance values indicate greater cell viability. Our results showed no significant reduction in cell viability across all LNP concentrations, demonstrating that the LNPs did not induce cytotoxic effects. This finding is crucial for ensuring that the LNPs are safe for biological use, supporting their potential in clinical applications such as drug delivery and gene therapy. Overall, the MTT assay provided strong evidence of the biocompatibility of our LNPs. </p>
          <H5 text="Proliferation Assay to Monitor Long-Term Safety"></H5>
            <p>In addition to assessing immediate cytotoxicity, we also evaluated the long-term safety of the LNPs by conducting a proliferation assay. This assay tracked cell division and growth over time to determine whether the LNPs impacted cellular function. Our results showed that LNP-treated cells had similar growth rates to untreated controls, indicating that the LNPs do not interfere with normal cell processes. This further confirms their biocompatibility and suitability for use in biological systems.</p>
          </Subesction>
          <Subesction title="Transfection Efficiency" id="Transfection Efficiency">
          <H5 text="Transfection with LNPs"></H5> 
            <p></p>
          <H5 text="Fluorescence-Activated Cell Sorting (FACS)"></H5> 
            <p>To assess the transfection efficiency of our LNPs, we used fluorescence-activated cell sorting (FACS). This method involved tagging the LNPs with fluorescent markers and measuring their ability to deliver genetic material into target cells. FACS provided quantitative insights into how effectively the LNPs transfected cells, helping us optimize their design for gene therapy applications. </p>
          </Subesction>

          <Subesction title="In-Depth Characterization of LNPs" id="In-Depth Characterization of LNPs">
          <H5 text="Dynamic Light Scattering (DLS) and Zeta Potential"></H5> 
            <p>We used dynamic light scattering (DLS) to measure the size distribution and polydispersity index (PDI) of our LNPs. This technique allowed us to confirm that the LNPs had a consistent size distribution with minimal aggregation, which is essential for their stability. Additionally, we measured the zeta potential of the LNPs to assess their surface charge. A high zeta potential confirmed that the LNPs were stable in suspension, which is critical for their effectiveness in biological environments. </p>
          <H5 text="Scanning Electron Microscopy (SEM) and Cryo-TEM for Structural Analysis"></H5>
            <p>To further characterize the morphology and surface structure of the LNPs, we employed scanning electron microscopy (SEM). SEM provided high-resolution images that confirmed the spherical shape and uniformity of the LNPs. Additionally, cryo-transmission electron microscopy (cryo-TEM) allowed us to investigate the internal structure of the LNPs, revealing the presence of lipid layers and encapsulated materials, which are crucial for understanding their function in drug delivery. </p>
          <H5 text="DNase Assay for Stability of Encapsulated Material "></H5> 
            <p>Finally, we conducted a DNase assay to evaluate whether the LNPs could protect encapsulated nucleic acids, such as mRNA, from enzymatic degradation. This assay demonstrated that the LNPs successfully shielded the genetic material, ensuring its stability until it reaches target cells. </p>
          </Subesction>

          <Subesction title="Conclusion" id="Conclusion">
          <H5 text="Importance of Safety in LNP Development"></H5>
            <p>Testing the safety of our LNPs was a critical step in their development. LNPs are increasingly being used in cutting-edge therapies, such as mRNA vaccines and targeted drug delivery systems. For these technologies to be viable, the nanoparticles must not harm the cells they are intended to interact with. The MTT and proliferation assays provided robust data, confirming the biocompatibility of our LNPs and reinforcing their potential for safe use in further research and clinical applications. </p>
          </Subesction>
     
        </Section>
        <Section title="References" id="References">
         <MethodSources/>
        </Section>

        

        
      </>
    );
  }
  